@@ -22,9 +22,9 @@ use nom::multi::separated_list1;
 use nom::sequence::{preceded, tuple};
 use nom::{Err, IResult};
 
-pub use range::Range;
+pub use range::*;
 
-pub mod range;
+mod range;
 
 /// JavaScript's
 /// [MAX_SAFE_INTEGER](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Number/MAX_SAFE_INTEGER).
